@@ -4,20 +4,16 @@ package App::ElasticSearch::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '7.9.2'; # VERSION
+our $VERSION = '7.1'; # VERSION
 
 our $_OPTIONS_PARSED;
 our %_GLOBALS = ();
 our @_CONFIGS = (
     '/etc/es-utils.yaml',
     '/etc/es-utils.yml',
+    "$ENV{HOME}/.es-utils.yaml",
+    "$ENV{HOME}/.es-utils.yml",
 );
-if( $ENV{HOME} ) {
-    push @_CONFIGS, map { "$ENV{HOME}/.es-utils.$_" } qw( yaml yml );
-
-    my $xdg_config_home = $ENV{XDG_CONFIG_HOME} || "$ENV{HOME}/.config";
-    push @_CONFIGS, map { "${xdg_config_home}/es-utils/config.$_" } qw( yaml yml );
-}
 
 use CLI::Helpers qw(:all);
 use Getopt::Long qw(:config pass_through);
@@ -61,7 +57,6 @@ use Sub::Exporter -setup => {
         es_optimize_index
         es_apply_index_settings
         es_local_index_meta
-        es_flatten_hash
     )],
     groups => {
         config  => [qw(es_globals)],
@@ -149,6 +144,8 @@ my %DEF = (
 );
 CLI::Helpers::override(verbose => 1) if $DEF{NOOP};
 
+my $BASE_URL = URI->new(sprintf "%s://%s:%d", @DEF{qw(PROTO HOST PORT)});
+
 if( $DEF{NOPROXY} ) {
     debug("Removing any active HTTP Proxies from ENV.");
     delete $ENV{$_} for qw(http_proxy HTTP_PROXY);
@@ -203,20 +200,9 @@ sub es_basic_auth {
     if( $DEF{HOST} eq $host ) {
         %auth = map { lc($_) => $DEF{$_} } qw(USERNAME PASSWORD);
     }
-    my %meta = ();
-    foreach my $k (qw( http-username password-exec )) {
-        foreach my $name ( $DEF{INDEX}, $DEF{BASE} ) {
-            next unless $name;
-            if( my $v = es_local_index_meta($k, $name) ) {
-                $meta{$k} = $v;
-                last;
-            }
-        }
-    }
 
     # Get the Username
-    $auth{username} ||= $meta{'http-username'} ? $meta{'http-username'}
-                      : defined $DEF{USERNAME} ? $DEF{USERNAME}
+    $auth{username} ||= defined $DEF{USERNAME} ? $DEF{USERNAME}
                       : defined $netrc         ? $netrc->login
                       : prompt("Username for '$host': ",
                             defined $DEF{USERNAME} ? (default => $DEF{USERNAME}) : ()
@@ -224,7 +210,7 @@ sub es_basic_auth {
 
     # Prompt for the password
     $auth{password} ||= defined $netrc ? $netrc->password
-                      : (es_pass_exec($host,$auth{username},$meta{'password-exec'})
+                      : (es_pass_exec($host,$auth{username})
                             || prompt(sprintf "Password for '%s' at '%s': ", $auth{username}, $host)
                         );
 
@@ -235,20 +221,19 @@ sub es_basic_auth {
 
 
 sub es_pass_exec {
-    my ($host,$username,$exec) = @_;
+    my ($host,$username) = @_;
     # Simplest case we can't run
-    $exec ||= $DEF{PASSEXEC};
-    return unless -x $exec;
+    return unless $DEF{PASSEXEC} and -x $DEF{PASSEXEC};
 
     my(@out,@err);
     # Run the password command captue out, error and RC
-    run3 [ $exec, $host, $username ], \undef, \@out, \@err;
+    run3 [ $DEF{PASSEXEC}, $host, $username ], \undef, \@out, \@err;
     my $rc = $?;
 
     # Record the error
     if( @err or $rc != 0 ) {
         output({color=>'red',stderr=>1},
-            sprintf("es_pass_exec() called '%s' and met with an error code '%d'", $exec, $rc),
+            sprintf("es_pass_exec() called '%s' and met with an error code '%d'", $DEF{PASSEXEC}, $rc),
             @err
         );
         return;
@@ -275,7 +260,7 @@ sub es_pattern {
 sub _get_es_version {
     return $CURRENT_VERSION if defined $CURRENT_VERSION;
     my $conn = es_connect();
-    my $resp = $conn->ua->get( sprintf "%s://%s:%d", $conn->proto, $conn->host, $conn->port );
+    my $resp = $conn->ua->get( $BASE_URL->as_string );
     if( $resp->is_success ) {
         eval {
             $CURRENT_VERSION = join('.', (split /\./,$resp->content->{version}{number})[0,1]);
@@ -296,12 +281,9 @@ my $ES = undef;
 sub es_connect {
     my ($override_servers) = @_;
 
-    my %conn = (
-        host    => $DEF{HOST},
-        port    => $DEF{PORT},
-        proto   => $DEF{PROTO},
-        timeout => $DEF{TIMEOUT},
-    );
+    my $server = $DEF{HOST};
+    my $port   = $DEF{PORT};
+    my $proto  = $DEF{PROTO};
 
     # If we're overriding, return a unique handle
     if(defined $override_servers) {
@@ -309,7 +291,7 @@ sub es_connect {
         my @servers;
         foreach my $entry ( @overrides ) {
             my ($s,$p) = split /\:/, $entry;
-            $p ||= $conn{port};
+            $p ||= $port;
             push @servers, { host => $s, port => $p };
         }
 
@@ -318,21 +300,13 @@ sub es_connect {
             return App::ElasticSearch::Utilities::Connection->new(%{$pick});
         }
     }
-    else {
-        # Check for index metadata
-        foreach my $k ( keys %conn ) {
-            foreach my $name ( $DEF{INDEX}, $DEF{BASE} ) {
-                next unless $name;
-                if( my $v = es_local_index_meta($k => $name) ) {
-                    $conn{$k} = $v;
-                    last;
-                }
-            }
-        }
-    }
 
     # Otherwise, cache our handle
-    $ES ||= App::ElasticSearch::Utilities::Connection->new(%conn);
+    $ES ||= App::ElasticSearch::Utilities::Connection->new(
+        host  => $server,
+        port  => $port,
+        proto => $proto,
+    );
 
     return $ES;
 }
@@ -372,16 +346,16 @@ sub es_request {
     my $index;
 
     if( exists $options->{index} ) {
-        if( my $index_in = delete $options->{index} ) {
-            # No need to validate _all
-            if( $index_in eq '_all') {
-                $index = $index_in;
-            }
-            else {
-                # Validate each included index
-                my @indexes = is_arrayref($index_in) ? @{ $index_in } : split /\,/, $index_in;
-                $index = join(',', @indexes);
-            }
+        my $index_in = delete $options->{index};
+
+        # No need to validate _all
+        if( $index_in eq '_all') {
+            $index = $index_in;
+        }
+        else {
+            # Validate each included index
+            my @indexes = is_arrayref($index_in) ? @{ $index_in } : split /\,/, $index_in;
+            $index = join(',', @indexes);
         }
     }
 
@@ -398,6 +372,7 @@ sub es_request {
         $index = '';
     }
 
+
     # Figure out if we're modifying things
     my $modification = $url eq '_search' && $options->{method} eq 'POST' ? 0
                      : $options->{method} ne 'GET';
@@ -444,7 +419,7 @@ sub es_request {
             $msg = $resp->{message};
         };
         die sprintf "es_request(%s/%s) failed[%d]:\n%s",
-                    $index, $options->{command}, $resp->code, $msg || 'missing error message';
+                    $index, $options->{command}, $resp->code, $msg;
 
     } elsif( !defined $resp->content || ( !is_ref($resp->content) && !length $resp->content )) {
         output({color=>'yellow',stderr=>1},
@@ -684,11 +659,10 @@ sub es_index_fields {
         # Handle Version incompatibilities
         my $ref = exists $result->{$idx}{mappings} ? $result->{$idx}{mappings} : $result->{$idx};
 
-        # Loop through the mappings, skipping _default_, except on 7.x where we notice "properties"
-        my @mappings = exists $ref->{properties} ? ($ref)
-                     : map { $ref->{$_} } grep { $_ ne '_default_' } keys %{ $ref };
+        # Loop through the mappings, skipping _default_
+        my @mappings = grep { $_ ne '_default_' } keys %{ $ref };
         foreach my $mapping (@mappings) {
-            _find_fields(\%fields,$mapping);
+            _find_fields(\%fields,$ref->{$mapping});
         }
     }
     # Return the results
@@ -722,7 +696,6 @@ sub es_index_fields {
     sub _find_fields {
         my ($f,$ref,@path) = @_;
 
-        return unless is_hashref($ref);
         # Handle things with properties
         if( exists $ref->{properties} && is_hashref($ref->{properties}) ) {
             $nested_path = join('.', @path) if $ref->{type} and $ref->{type} eq 'nested';
@@ -860,14 +833,6 @@ sub es_node_stats {
 }
 
 
-sub es_flatten_hash {
-    my $hash = shift;
-    my $_flat = flatten($hash, { HashDelimiter=>':', ArrayDelimiter=>':' });
-    my %compat = map { s/:/./gr => $_flat->{$_} } keys %{ $_flat };
-    return \%compat;
-}
-
-
 sub def {
     my($key)= map { uc }@_;
 
@@ -908,7 +873,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 SYNOPSIS
 
@@ -1116,10 +1081,6 @@ Exposes GET /_nodes/stats
 
 Returns a hashref
 
-=head2 es_flatten_hash
-
-Performs flattening that's compatible with Elasticsearch's flattening.
-
 =head2 def('key')
 
 Exposes Definitions grabbed by options parsing
@@ -1148,7 +1109,6 @@ field it needs to sort documents, i.e.:
     meta:
       logstash:
         timestamp: '@timestamp'
-        host: es-cluster-01.int.example.com
       bro:
         timestamp: 'timestamp'
 
@@ -1177,8 +1137,7 @@ See also the "CONNECTION ARGUMENTS" and "INDEX SELECTION ARGUMENTS" sections fro
 
 =head1 ARGUMENT GLOBALS
 
-Some options may be specified in the B</etc/es-utils.yaml>, B<$HOME/.es-utils.yaml>
-or B<$HOME/.config/es-utils/config.yaml> file:
+Some options may be specified in the B</etc/es-utils.yaml> or B<$HOME/.es-utils.yaml> file:
 
     ---
     base: logstash
@@ -1412,7 +1371,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexey Shatlovsky Samit Badle Takumi Sakamoto Vitaly Shupak Surikov Andrei Grechkin Daniel Ostermeier Jason Rojas Kang-min Liu Lisa Hare Markus Linnala Matthew Feinberg Mohammad S Anwar
+=for stopwords Alexey Shatlovsky Surikov Daniel Ostermeier Jason Rojas Kang-min Liu Lisa Hare Markus Linnala Mohammad S Anwar Samit Badle Takumi Sakamoto
 
 =over 4
 
@@ -1422,26 +1381,10 @@ Alexey Shatlovsky <alexey.shatlovsky@booking.com>
 
 =item *
 
-Samit Badle <Samit.Badle@gmail.com>
-
-=item *
-
-Takumi Sakamoto <takumi.saka@gmail.com>
-
-=item *
-
-Vitaly Shupak <vitaly.shupak@deshaw.com>
-
-=item *
-
 Alexey Surikov <ksurent@gmail.com>
 
 =item *
 
-Andrei Grechkin <andrei.grechkin@booking.com>
-
-=item *
-
 Daniel Ostermeier <daniel.ostermeier@gmail.com>
 
 =item *
@@ -1462,15 +1405,19 @@ Markus Linnala <Markus.Linnala@cybercom.com>
 
 =item *
 
-Matthew Feinberg <mattf@intex.com>
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =item *
 
-Mohammad S Anwar <mohammad.anwar@yahoo.com>
+Samit Badle <Samit.Badle@gmail.com>
+
+=item *
+
+Takumi Sakamoto <takumi.saka@gmail.com>
 
 =back
 
-=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -1518,7 +1465,7 @@ L<https://github.com/reyjrar/es-utils>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
