@@ -5,7 +5,7 @@ package App::ElasticSearch::Utilities::Connection;
 use strict;
 use warnings;
 
-our $VERSION = '7.9.2'; # VERSION
+our $VERSION = '7.1'; # VERSION
 
 use App::ElasticSearch::Utilities::HTTPRequest;
 use CLI::Helpers qw(:output);
@@ -74,9 +74,8 @@ sub _build_ua {
     ## use critic
     my $ua = LWP::UserAgent->new(
         keep_alive        => 3,
-        agent             => sprintf("%s/%s (Perl %s)", __PACKAGE__, $local_version, $^V),
+        agent             => sprintf("%s/%0.1f (Perl %s)", __PACKAGE__, $local_version, $^V),
         protocols_allowed => [qw(http https)],
-        timeout           => $self->timeout,
     );
     debug({color=>'cyan'}, sprintf "Initialized a UA: %s", $ua->agent);
 
@@ -173,7 +172,7 @@ sub request {
     my $req = App::ElasticSearch::Utilities::HTTPRequest->new( $method => $uri->as_string );
     $req->content($body) if defined $body;
 
-    return $self->ua->request( $req );
+    return $self->ua->simple_request( $req );
 }
 
 
@@ -226,7 +225,7 @@ App::ElasticSearch::Utilities::Connection - Abstract the connection element
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 SYNOPSIS
 
@@ -314,7 +313,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
