@@ -4,29 +4,18 @@ package App::ElasticSearch::Utilities::Query;
 use strict;
 use warnings;
 
-our $VERSION = '7.9.2'; # VERSION
+our $VERSION = '7.1'; # VERSION
 
-use App::ElasticSearch::Utilities qw(es_request es_indices);
-use App::ElasticSearch::Utilities::Aggregations;
 use CLI::Helpers qw(:output);
 use Clone qw(clone);
-use Const::Fast;
 use Moo;
 use Ref::Util qw(is_arrayref is_hashref);
-use Types::Standard qw(ArrayRef Enum HashRef Int Maybe Str);
+use Types::Standard qw(ArrayRef HashRef Int Maybe Str);
 use Types::ElasticSearch qw(TimeConstant is_TimeConstant);
 use namespace::autoclean;
 
-const my $AGG_KEY => 'aggregations';
 my %TO = (
-    array_ref => sub { defined $_[0] && is_arrayref($_[0]) ? $_[0] : defined $_[0] ? [ $_[0] ] : $_[0] },
-);
-
-
-has fields_meta => (
-    is => 'rw',
-    isa => HashRef,
-    default => sub { {} },
+    array_ref => sub { defined $_[0] && ref($_[0]) eq 'ARRAY' ? $_[0] : defined $_[0] ? [ $_[0] ] : $_[0] },
 );
 
 
@@ -39,44 +28,29 @@ has query_stash => (
 );
 
 
-has scroll_id => (
-    is       => 'rw',
-    isa      => Str,
-    init_arg => undef,
-    writer   => 'set_scroll_id',
-    clearer  => 1,
-);
-
-
-
 my %QUERY = (
-    must        => { isa => ArrayRef, coerce => $TO{array_ref} },
-    must_not    => { isa => ArrayRef, coerce => $TO{array_ref} },
-    should      => { isa => ArrayRef, coerce => $TO{array_ref} },
-    filter      => { isa => ArrayRef, coerce => $TO{array_ref} },
-    nested      => { isa => HashRef },
-    nested_path => { isa => Str },
-    minimum_should_match => { isa => Str },
+    must        => { default => sub {undef}, isa => Maybe[ArrayRef], coerce => $TO{array_ref}, init_arg => 'must'     },
+    must_not    => { default => sub {undef}, isa => Maybe[ArrayRef], coerce => $TO{array_ref}, init_arg => 'must_not' },
+    should      => { default => sub {undef}, isa => Maybe[ArrayRef], coerce => $TO{array_ref}, init_arg => 'should'   },
+    filter      => { default => sub {undef}, isa => Maybe[ArrayRef], coerce => $TO{array_ref}, init_arg => 'filter'   },
+    nested      => { default => sub {undef}, isa => Maybe[HashRef], init_arg => 'nested' },
+    nested_path => { default => sub {undef}, isa => Maybe[Str],     init_arg => 'nested_path' },
 );
 
 
 my %REQUEST_BODY = (
-    from         => { isa => Int },
+    from         => { isa => Maybe[Int] },
     size         => { default => sub {50},    isa => Int },
-    fields       => { isa => ArrayRef, coerce => $TO{array_ref} },
-    sort         => { isa => ArrayRef, coerce => $TO{array_ref} },
-    aggregations => { isa => HashRef },
+    fields       => { isa => Maybe[ArrayRef], coerce => $TO{array_ref} },
+    sort         => { isa => Maybe[ArrayRef], coerce => $TO{array_ref} },
+    aggregations => { isa => Maybe[HashRef] },
 );
 
 
 my %PARAMS = (
-    scroll           => { isa => Maybe[TimeConstant] },
-    timeout          => { isa => TimeConstant },
-    terminate_after  => { isa => Int },
-    track_total_hits => { isa => Enum[qw( true false )], default => sub { 'true' } },
-    track_scores     => { isa => Enum[qw( true false )] },
-    search_type      => { isa => Enum[qw( dfs_query_then_fetch query_then_fetch )] },
-    rest_total_hits_as_int => { isa => Enum[qw( true false )], default => sub { 'true' } },
+    scroll          => { isa => Maybe[TimeConstant] },
+    timeout         => { isa => TimeConstant },
+    terminate_after => { isa => Int },
 );
 
 # Dynamically build our attributes
@@ -85,6 +59,7 @@ foreach my $attr (keys %QUERY) {
         is       => 'rw',
         lazy     => 1,
         writer   => "set_$attr",
+        init_arg => undef,
         %{ $QUERY{$attr} },
     );
 }
@@ -102,78 +77,24 @@ foreach my $attr (keys %PARAMS) {
         is       => 'rw',
         lazy     => 1,
         writer   => "set_$attr",
+        init_arg => undef,
         %{ $PARAMS{$attr} },
     );
 }
 
 
-sub as_search {
-    my ($self,$indexes) = @_;
-    return (
-        _search => {
-            index     => $indexes,
-            uri_param => $self->uri_params,
-            method    => 'POST',
-        },
-        $self->request_body,
-    );
-}
-
-
-sub execute {
-    my($self,$indexes) = @_;
-
-    # Default to context based indexes
-    $indexes ||= es_indices();
-
-    my $result = es_request( $self->as_search($indexes) );
-
-    if( $result->{_scroll_id} ) {
-        $self->set_scroll_id($result->{_scroll_id})
-    }
-
-    return $result;
-}
-
-
-sub scroll_results {
-    my($self) = @_;
-    my $result;
-    if( $self->scroll_id ) {
-        $result = es_request( '_search/scroll',
-                { method => 'POST' },
-                {
-                    scroll => $self->scroll,
-                    scroll_id => $self->scroll_id,
-                }
-        );
-        if( $result && $result->{_scroll_id} ) {
-            $self->set_scroll_id($result->{_scroll_id})
-        }
-        else {
-            $self->clear_scroll_id();
-        }
-    }
-    return $result ? $result : ();
-}
-
-
 sub uri_params {
     my $self = shift;
 
     my %params=();
     foreach my $field (keys %PARAMS) {
-        my $v;
-        eval {
+        my $v = eval {
+            debug({color=>'magenta'}, "uri_params() - retrieving param '$field'");
             ## no critic
             no strict 'refs';
-            $v = $self->$field();
+            $self->$field();
             ## user critic
         };
-        debug({color=>'magenta'}, sprintf "uri_params() - retrieving param '%s' got '%s'",
-                $field, ( defined $v ? $v : '' ),
-        );
-
         next unless defined $v;
         $params{$field} = $v;
     }
@@ -185,22 +106,19 @@ sub request_body {
     my $self = shift;
 
     my %body = ();
-    my %map  = qw( fields _source );
     foreach my $section (keys %REQUEST_BODY) {
-        my $val;
         eval {
+            debug({color=>'yellow'}, "request_body() - retrieving section '$section'");
             ## no critic
             no strict 'refs';
-            $val = $self->$section;
+            $body{$section} = $self->$section;
             ## use critic
+            delete $body{$section} unless defined $body{$section};
+            debug_var({color=>'cyan'},$body{$section}) if defined $body{$section} and ref $body{$section};
             1;
         } or do {
             debug({color=>'red'}, "request_body() - Failed to retrieve '$section'");
         };
-        next unless defined $val;
-        my $data = { $section => $val };
-        my $param = $map{$section} || $section;
-        $body{$param} = $val;
     }
     $body{query} = $self->query;
     return \%body;
@@ -240,7 +158,7 @@ sub query {
             if($self->stash($k)) {
                 push @{ $bool{$k} }, $self->stash($k);
             }
-            delete $bool{$k} if exists $bool{$k} and is_arrayref($bool{$k}) and not @{ $bool{$k} };
+            delete $bool{$k} if exists $bool{$k} and not @{ $bool{$k} };
         }
         $qref = { bool => \%bool };
     }
@@ -267,52 +185,17 @@ sub add_aggregations {
 sub wrap_aggregations {
     my $self = shift;
     my %wrapper = @_;
-    my $aggs = $self->aggregations;
-
-    if( keys %{ $aggs } ) {
-        foreach my $a (keys %wrapper) {
-            $wrapper{$a}->{$AGG_KEY} = clone $aggs;
-        }
+    foreach my $a (keys %wrapper) {
+        $wrapper{$a}->{aggs} = clone $self->aggregations;
     }
-
     $self->set_aggregations(\%wrapper);
 }
 
-
-sub aggregations_by {
-    my ($self,$dir,$aggs) = @_;
-
-    my @sort = ();
-    my %aggs = ();
-    foreach my $def (@{ $aggs }) {
-        my ($name,$agg) = %{ expand_aggregate_string($def) };
-        next unless is_single_stat(keys %{ $agg });
-        $aggs{$name} = $agg;
-        push @sort, { $name => $dir };
-    }
-    if( @sort ) {
-        push @sort, { '_count' => 'desc' };
-
-        my $ref_aggs = $self->aggregations;
-        foreach my $name ( keys %{ $ref_aggs } ) {
-            foreach my $k ( keys %{ $ref_aggs->{$name} } ) {
-                next if $k eq $AGG_KEY;
-                $ref_aggs->{$name}{$k}{order} = \@sort;
-                foreach my $agg (keys %aggs) {
-                    $ref_aggs->{$name}{$AGG_KEY}{$agg} = $aggs{$agg};
-                }
-            }
-        }
-        $self->set_aggregations( $ref_aggs );
-    }
-}
-
 # Support Short-hand like ES
 *aggs      = \&aggregations;
 *set_aggs  = \&set_aggregations;
 *add_aggs  = \&add_aggregations;
 *wrap_aggs = \&wrap_aggregations;
-*aggs_by   = \&aggregations_by;
 
 
 
@@ -344,14 +227,15 @@ sub set_match_all {
 
 
 sub add_bool {
-    my $self  = shift;
-    my %bools = @_;
-    foreach my $section ( sort keys %bools ) {
-        next unless exists $QUERY{$section};
+    my $self      = shift;
+    my $section   = shift;
+    my $condition = shift;
+
+    if( exists $QUERY{$section} ) {
         ## no critic
         no strict 'refs';
         my $set = $self->$section;
-        push @{ $set }, $bools{$section};
+        push @{ $set }, $condition;
         my $setter = "set_$section";
         $self->$setter($set);
         ## use critic
@@ -368,8 +252,6 @@ sub stash {
         if( defined $condition ) {
             debug({color=>exists $stash->{$section} ? 'green' : 'red' }, "setting $section in stash");
             $stash->{$section} = $condition;
-            # Reset Scroll ID
-            $self->clear_scroll_id();
         }
     }
     return exists $stash->{$section} ? $stash->{$section} : undef;
@@ -388,23 +270,14 @@ App::ElasticSearch::Utilities::Query - Object representing ES Queries
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 ATTRIBUTES
 
-=head2 fields_meta
-
-A hash reference with the field data from L<App::ElasticSearch::Utilities::es_index_fields>.
-
 =head2 query_stash
 
 Hash reference containing replaceable query elements.  See L<stash>.
 
-=head2 scroll_id
-
-The scroll id for the last executed query.  You shouldn't mess with this
-directly. It's best to use the L<execute()> and L<scroll_results()> methods.
-
 =head2 must
 
 The must section of a bool query as an array reference.  See: L<add_bool>
@@ -420,11 +293,6 @@ Can be set using set_must_not and is a valid init_arg.
 The should section of a bool query as an array reference.  See: L<add_bool>
 Can be set using set_should and is a valid init_arg.
 
-=head2 minimum_should_match
-
-A string defining the minimum number of should conditions to qualify a match.
-See L<https://www.elastic.co/guide/en/elasticsearch/reference/7.3/query-dsl-minimum-should-match.html>
-
 =head2 filter
 
 The filter section of a bool query as an array reference.  See: L<add_bool>
@@ -488,43 +356,8 @@ large queries where you are protecting against OOM Errors. The B<size> attribute
 truncation occurs after the reduce operation, where B<terminate_after> occurs during the map phase of the query.
 Can be set with B<set_terminateafter>.  Cannot be an init_arg.
 
-=head2 track_total_hits
-
-Should the query attempt to calculate the number of hits the query would match.
-Defaults to C<true>.
-
-=head2 track_scores
-
-Set to true to score every hit in the search results, set to false to not
-report scores.  Defaults to unset, i.e., use the ElasticSearch default.
-
-=head2 rest_total_hits_as_int
-
-In ElasticSearch 7.0, the total hits element became a hash reference with more
-details.  Since most of the tooling relies on the old behavior, this defaults
-to C<true>.
-
-=head2 search_type
-
-Choose an execution path for the query.  This is null by default, but you can
-set it to a valid `search_type` setting, see:
-L<https://www.elastic.co/guide/en/elasticsearch/reference/current/search-request-body.html#request-body-search-search-type>
-
 =head1 METHODS
 
-=head2 as_search( [ 'index1', 'index2' ] )
-
-Returns a list of parameters to pass directly to C<es_request()>.
-
-=head2 execute( [ $index1, $index2 ] )
-
-Uses `es_request()` to return the result, stores any relevant scroll data.
-
-=head2 scroll_results()
-
-If a scroll has been set, this will construct and run the requisite scroll
-search, otherwise it returns undef.
-
 =head2 uri_params()
 
 Retrieves the URI parameters for the query as a hash reference.  Undefined parameters
@@ -549,7 +382,7 @@ The value being the hash reference representation of the aggregation itself.
 It will silently replace a previously named aggregation with the most recent
 call.
 
-Calling this function overrides the L<size> element to B<0> and disables L<scroll>.
+Calling this function overrides the L<size> element to B<0> and L<scroll> to undef.
 
 Aliased as B<add_aggs>.
 
@@ -557,7 +390,7 @@ Aliased as B<add_aggs>.
 
 Use this to wrap an aggregation in another aggregation.  For example:
 
-    $q->add_aggregations(ip => { terms => { field => src_ip } });
+    $q->add_aggregation(ip => { terms => { field => src_ip } });
 
 Creates:
 
@@ -595,20 +428,6 @@ Which translates the query into:
         }
     }
 
-=head2 aggregations_by( [asc | desc] => aggregation_string )
-
-Applies a sort to all aggregations at the current level based on the
-aggregation string.
-
-Aggregation strings are parsed with the
-L<App::ElasticSearch::Utilities::Aggregations> C<expand_aggregate_string()>
-functions.
-
-Examples:
-
-    $q->aggregations_by( desc => [ qw( sum:bytes ) ] );
-    $q->aggregations_by( desc => [ qw( sum:bytes cardinality:user_agent ) ] );
-
 =head2 set_scan_scroll($ctxt_life)
 
 This function emulates the old scan scroll feature in early version of Elasticsearch. It takes
@@ -623,23 +442,11 @@ but defaults to '1m'.  It is the same as calling:
 This method clears all filters and query elements to and sets the must to match_all.
 It will not reset other parameters like size, sort, and aggregations.
 
-=head2 add_bool( section => conditions .. )
+=head2 add_bool( section => condition )
 
 Appends a search condition to a section in the query body.  Valid query body
 points are: must, must_not, should, and filter.
 
-    $q->add_bool( must => { term => { http_status => 200 } } );
-
-    # or
-
-    $q->add_bool(
-        must => [
-            { term => { http_method => 'GET' } }
-            { term => { client_ip   => '10.10.10.1' } }
-        ]
-        must_not => { term => { http_status => 400 } },
-    );
-
 =head2 stash( section => condition )
 
 Allows a replaceable query element to exist in the query body sections: must, must_not,
@@ -663,7 +470,6 @@ This allows re-use of the query object inside of loops like this.
 =for Pod::Coverage set_aggs
 =for Pod::Coverage add_aggs
 =for Pod::Coverage wrap_aggs
-=for Pod::Coverage aggs_by
 
 =head1 AUTHOR
 
@@ -671,7 +477,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
