@@ -3,9 +3,8 @@ package App::ElasticSearch::Utilities::VersionHacks;
 
 use strict;
 use warnings;
-use version;
 
-our $VERSION = '7.9.2'; # VERSION
+our $VERSION = '7.1'; # VERSION
 
 use Const::Fast;
 use CLI::Helpers qw(:all);
@@ -45,9 +44,6 @@ my %CALLBACKS = (
     '_cluster/state' => {
         default => \&_cluster_state_1_0,
     },
-    '_search' => {
-        default => \&_search_params,
-    },
 );
 
 my $version;
@@ -101,7 +97,7 @@ sub _fix_version_request {
             }
             elsif(exists $CALLBACKS{$url}->{default}) {
                 debug({indent=>1,color=>'yellow'}, "+ Callback dispatched for $url by default rule");
-                ($url,$options,$data) = $CALLBACKS{$url}->{default}->($url,$options,$data,$version);
+                ($url,$options,$data) = $CALLBACKS{$url}->{default}->($url,$options,$data);
             }
         }
     }
@@ -154,23 +150,6 @@ sub _cluster_state_1_0 {
     return ($url,$options,$data);
 }
 
-sub _search_params {
-    my ($url,$options,$data,$version) = @_;
-
-    my @invalid = ();
-    push @invalid, "track_total_hits"       if qv($version) < qv("6.0.0");
-    push @invalid, "rest_total_hits_as_int" if qv($version) < qv("7.0.0");
-
-    if( @invalid && exists $options->{uri_param} ) {
-        foreach my $invalid ( @invalid ) {
-            delete $options->{uri_param}{$invalid}
-                if exists $options->{uri_param}{$invalid};
-        }
-    }
-
-    return ($url,$options,$data);
-}
-
 1;
 
 __END__
@@ -183,7 +162,7 @@ App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 AUTHOR
 
@@ -191,7 +170,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
