@@ -7,6 +7,7 @@ use warnings;
 use App::ElasticSearch::Utilities qw(:all);
 use CLI::Helpers qw(:all);
 use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
+use Hash::Flatten qw(flatten);
 use Pod::Usage;
 use POSIX qw(ceil);
 
@@ -123,7 +124,7 @@ foreach my $index (sort @indices) {
             last if $skipped;
         }
         if( $skipped ) {
-            output("$index contains a skipped alias: $skipped");
+            verbose({color=>'blue'},"$index contains a skipped alias: $skipped");
             next;
         }
     }
@@ -240,7 +241,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 SYNOPSIS
 
@@ -377,7 +378,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
