@@ -4,8 +4,9 @@
 use strict;
 use warnings;
 
-use App::ElasticSearch::Utilities qw(es_request es_node_stats es_index_stats es_index_strip_date es_flatten_hash);
+use App::ElasticSearch::Utilities qw(es_request es_node_stats es_index_stats es_index_strip_date);
 use CLI::Helpers qw(:all);
+use Hash::Flatten qw(flatten);
 use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
 use IO::Socket::INET;
 use Pod::Usage;
@@ -137,7 +138,7 @@ sub index_blocks {
     my %collected=();
     foreach my $idx ( keys %{ $result } ) {
         if( $result->{$idx}{settings} ) {
-            my $settings = es_flatten_hash( $result->{$idx}{settings} );
+            my $settings = flatten( $result->{$idx}{settings} );
             foreach my $block ( keys %{ $settings } ) {
                 my $value = $settings->{$block};
                 if( lc $value eq 'true') {
@@ -174,9 +175,6 @@ sub local_shard_data {
 
     my %results;
     foreach my $shard ( @{ $shardres } ) {
-        # Skip unallocated shards
-        next unless $shard->{id};
-
         # Skip unless this shard is allocated to this shard
         next unless $shard->{id} eq $id;
 
@@ -291,7 +289,7 @@ es-graphite-dynamic.pl - Dynamically gather metrics and send to graphite
 
 =head1 VERSION
 
-version 7.9.2
+version 7.1
 
 =head1 SYNOPSIS
 
@@ -407,7 +405,7 @@ you could:
 
 Or with the file collector, you could cron this:
 
-    es-graphite-dynamic.pl --local --prefix elasticsearch --data-file /tmp/diamond/elasticsearch.out --quiet
+    es-graphite-dynamic.pl --loocal --prefix elasticsearch --data-file /tmp/diamond/elasticsearch.out --quiet
 
 If not specified, the assumption is data will be going directly to graphite and the metric path will be set as:
 
@@ -425,7 +423,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
